import java.io.*;
import java.util.Date;
import java.text.DateFormat;
import java.text.SimpleDateFormat;

public class Main
{
    private static String inputFilename;
    private static File xmlFile;
    private static FileWriter fw;

    public static void main(String[] args) throws IOException
    {
        if (args.length == 1 && (args[0].equals("-h") || args[0].equals("--help"))) {
            //System.out.println("\n Usage: java -jar Parse_WIFI_users_XML.jar [inputFileACS.csv] [outputXMLFile.xml]\n");
            System.out.println("\n Usage: java -jar Parse_WIFI_users_XML.jar [inputFileACS.csv]\n");
        }
        else if (args.length == 1) {
            inputFilename = args[0];
            DateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd-HH-mm-ss");
            xmlFile = new File(System.getProperty("user.dir"), "WIFI_users_" + dateFormat.format(new Date()) + ".xml");
            if(xmlFile.exists()) { xmlFile.delete(); xmlFile.createNewFile(); }
            convert();
            System.out.print(xmlFile.getName() + "\n\n");
        }
        else {
            System.out.println("\n Incorrect usage! \n");
            System.out.println(" Usage: java -jar WIFI_users_XML.jar [inputFileACS.csv]\n");
        }

    }

    private static void convert() throws IOException {
        File csvFile = new File("." + File.separator + inputFilename);
        BufferedReader br = new BufferedReader(new FileReader(csvFile));

        fw = new FileWriter(xmlFile, true);
        writeInitialTags();

        boolean firstRow = true;
        int counter = 0;
        String ln;
        while ((ln = br.readLine()) != null) {
            if(firstRow) { firstRow = false; continue; }

            String[] spl = ln.split(",");
            String user = spl[0];
            String passwd = spl[11];
            String vlan;
            if (spl.length >= 16) {
                vlan = spl[15];
                writeLine(user, passwd, vlan);
                ++counter;
            }
            else {
                vlan = "-1"; // Campo VLAN del exportACS esta vacio
                System.out.println("\n Not including user " + user + " since it has no VLAN assigned");
            }
        }

        br.close();

        writeFinalTags();
        fw.close();

        System.out.print("\n > " + counter + " entries have been parsed to the XML file: ");
    }

    private static void writeInitialTags() throws IOException {
        fw.write(
                "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?>\n" +
                "<TipsContents xmlns=\"http://www.avendasys.com/tipsapiDefs/1.0\">\n" +
                "  <TipsHeader exportTime=\"Thu Feb 07 11:35:37 CET 2019\" version=\"6.7\"/>\n" +
                "  <LocalUsers>\n"
                );
    }

    private static void writeLine(String user, String passwd, String vlan) throws IOException {
        fw.write(
                "    <LocalUser changePwdNextLogin=\"false\" enabled=\"true\" roleName=\"[MAC Caching]\" passwordNtlmHash=\"\" passwordHash=\"\" password=\"" + passwd + "\" userName=\"" + user + "\" userId=\"" + user + "\">\n" +
                        "      <LocalUserTags tagName=\"Vlan\" tagValue=\"" + vlan + "\"/>\n" +
                        "    </LocalUser>\n"
        );
    }

    private static void writeFinalTags() throws IOException {
        fw.write(
                "  </LocalUsers>\n" +
                "  <Roles>\n" +
                "    <Role description=\"Default role applied during MAC caching\" name=\"[MAC Caching]\"/>\n" +
                "  </Roles>\n" +
                "  <TagDictionaries>\n" +
                "    <TagDictionary allowMultiple=\"true\" mandatory=\"false\" dataType=\"String\" attributeName=\"Vlan\" entityName=\"LocalUser\"/>\n" +
                "  </TagDictionaries>\n" +
                "</TipsContents>\n"
        );
    }

}
